@@ -4,9 +4,9 @@ UNDEFINED = runtime.UNDEFINED
 __M_dict_builtin = dict
 __M_locals_builtin = locals
 _magic_number = 8
-_modified_time = 1336407223.622515
+_modified_time = 1360321968.676882
 _enable_loop = True
-_template_filename = '/mnt/md0/MyWork/MyProjects/PyCK/pyck/forms/templates/form_as_table.mako'
+_template_filename = '/MyWork/Projects/PyCK/pyck/forms/templates/form_as_table.mako'
 _template_uri = 'form_as_table.mako'
 _source_encoding = 'utf8'
 _exports = []
@@ -43,14 +43,12 @@ def render_body(context,**pageargs):
         if include_table_tag:
             # SOURCE LINE 13
             __M_writer(u'<table>\n')
-            pass
         # SOURCE LINE 15
         if form._use_csrf_protection:
             # SOURCE LINE 16
             __M_writer(u'    <input type="hidden" name="csrf_token" value="')
             __M_writer(unicode(form._csrf_token))
             __M_writer(u'" />\n')
-            pass
         # SOURCE LINE 18
         if '_csrf' in form.errors:
             # SOURCE LINE 19
@@ -59,7 +57,6 @@ def render_body(context,**pageargs):
             __M_writer(u'">')
             __M_writer(unicode(form.errors['_csrf'][0]))
             __M_writer(u'</td></tr>\n')
-            pass
         # SOURCE LINE 21
         for field in form:
             # SOURCE LINE 22
@@ -90,14 +87,12 @@ def render_body(context,**pageargs):
                     __M_writer(u'        ')
                     __M_writer(unicode(field_label))
                     __M_writer(u'\n')
-                    pass
                 # SOURCE LINE 38
                 if 'left'==errors_position:
                     # SOURCE LINE 39
                     __M_writer(u'        ')
                     __M_writer(unicode(field_errors))
                     __M_writer(u'\n')
-                    pass
                 # SOURCE LINE 41
                 __M_writer(u'        ')
                 __M_writer(unicode(field_content))
@@ -108,14 +103,12 @@ def render_body(context,**pageargs):
                     __M_writer(u'        ')
                     __M_writer(unicode(field_label))
                     __M_writer(u'\n')
-                    pass
                 # SOURCE LINE 45
                 if 'right'==errors_position:
                     # SOURCE LINE 46
                     __M_writer(u'        ')
                     __M_writer(unicode(field_errors))
                     __M_writer(u'\n')
-                    pass
                 # SOURCE LINE 48
                 __M_writer(u'    </tr>\n')
                 # SOURCE LINE 49
@@ -128,14 +121,12 @@ def render_body(context,**pageargs):
                     __M_writer(u'        <tr>')
                     __M_writer(unicode(field_label))
                     __M_writer(u'</tr>\n')
-                    pass
                 # SOURCE LINE 56
                 if 'top'==errors_position:
                     # SOURCE LINE 57
                     __M_writer(u'        <tr>')
                     __M_writer(unicode(field_errors))
                     __M_writer(u'</tr>\n')
-                    pass
                 # SOURCE LINE 59
                 __M_writer(u'        <tr>')
                 __M_writer(unicode(field_content))
@@ -146,14 +137,12 @@ def render_body(context,**pageargs):
                     __M_writer(u'        <tr>')
                     __M_writer(unicode(field_label))
                     __M_writer(u'</tr>\n')
-                    pass
                 # SOURCE LINE 63
                 if 'bottom'==errors_position:
                     # SOURCE LINE 64
                     __M_writer(u'        <tr>')
                     __M_writer(unicode(field_errors))
                     __M_writer(u'</tr>\n')
-                    pass
                 # SOURCE LINE 66
                 __M_writer(u'        </table>\n    </td>\n    </tr>\n')
                 # SOURCE LINE 69
@@ -172,7 +161,6 @@ def render_body(context,**pageargs):
                     __M_writer(u'        <tr>')
                     __M_writer(unicode(field_label))
                     __M_writer(u' ')
-                    pass
                 # SOURCE LINE 79
                 __M_writer(u'        ')
                 # SOURCE LINE 80
@@ -187,7 +175,6 @@ def render_body(context,**pageargs):
                     __M_writer(u'        <tr>')
                     __M_writer(unicode(field_errors))
                     __M_writer(u' ')
-                    pass
                 # SOURCE LINE 86
                 __M_writer(u'        ')
                 # SOURCE LINE 87
@@ -207,7 +194,6 @@ def render_body(context,**pageargs):
                     __M_writer(u'        ')
                     __M_writer(unicode(field_label))
                     __M_writer(u'</tr>\n')
-                    pass
                 # SOURCE LINE 95
                 __M_writer(u'        ')
                 # SOURCE LINE 96
@@ -223,18 +209,14 @@ def render_body(context,**pageargs):
                     __M_writer(u'        ')
                     __M_writer(unicode(field_errors))
                     __M_writer(u'</tr>\n')
-                    pass
                 # SOURCE LINE 102
                 __M_writer(u'        </table>\n    </td>\n    </tr>\n')
-                pass
             # SOURCE LINE 106
             __M_writer(u'    \n')
-            pass
         # SOURCE LINE 108
         if include_table_tag:
             # SOURCE LINE 109
             __M_writer(u'</table>\n')
-            pass
         return ''
     finally:
         context.caller_stack._pop_frame()
